==> matrix_api_lite-0.1.8.tar.gz: lib/matrix_api_lite.dart <==
/* MIT License
* 
* Copyright (C) 2019, 2020, 2021 Famedly GmbH
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/

library matrix_api_lite;

export 'src/matrix_api.dart';
export 'src/utils/logs.dart';
export 'src/utils/map_copy_extension.dart';
export 'src/utils/try_get_map_extension.dart';
export 'src/model/algorithm_types.dart';
export 'src/model/basic_event.dart';
export 'src/model/basic_event_with_sender.dart';
export 'src/model/basic_room_event.dart';
export 'src/model/device.dart';
export 'src/model/event_context.dart';
export 'src/model/event_types.dart';
export 'src/model/events_sync_update.dart';
export 'src/model/filter.dart';
export 'src/model/keys_query_response.dart';
export 'src/model/login_response.dart';
export 'src/model/login_types.dart';
export 'src/model/matrix_connection_exception.dart';
export 'src/model/matrix_event.dart';
export 'src/model/matrix_exception.dart';
export 'src/model/matrix_keys.dart';
export 'src/model/message_types.dart';
export 'src/model/notifications_query_response.dart';
export 'src/model/one_time_keys_claim_response.dart';
export 'src/model/open_graph_data.dart';
export 'src/model/open_id_credentials.dart';
export 'src/model/presence.dart';
export 'src/model/presence_content.dart';
export 'src/model/profile.dart';
export 'src/model/public_rooms_response.dart';
export 'src/model/push_rule_set.dart';
export 'src/model/pusher.dart';
export 'src/model/request_token_response.dart';
export 'src/model/room_alias_informations.dart';
export 'src/model/room_keys_info.dart';
export 'src/model/room_keys_keys.dart';
export 'src/model/room_summary.dart';
export 'src/model/server_capabilities.dart';
export 'src/model/stripped_state_event.dart';
export 'src/model/supported_protocol.dart';
export 'src/model/supported_versions.dart';
export 'src/model/sync_update.dart';
export 'src/model/tag.dart';
export 'src/model/third_party_identifier.dart';
export 'src/model/third_party_location.dart';
export 'src/model/third_party_user.dart';
export 'src/model/timeline_history_response.dart';
export 'src/model/turn_server_credentials.dart';
export 'src/model/upload_key_signatures_response.dart';
export 'src/model/user_search_result.dart';
export 'src/model/well_known_informations.dart';
export 'src/model/who_is_info.dart';
export 'src/model/auth/authentication_data.dart';
export 'src/model/auth/authentication_identifier.dart';
export 'src/model/auth/authentication_password.dart';
export 'src/model/auth/authentication_phone_identifier.dart';
export 'src/model/auth/authentication_recaptcha.dart';
export 'src/model/auth/authentication_third_party_identifier.dart';
export 'src/model/auth/authentication_three_pid_creds.dart';
export 'src/model/auth/authentication_token.dart';
export 'src/model/auth/authentication_types.dart';
export 'src/model/auth/authentication_user_identifier.dart';
export 'src/model/events/forwarded_room_key_content.dart';
export 'src/model/events/olm_plaintext_payload.dart';
export 'src/model/events/room_encrypted_content.dart';
export 'src/model/events/room_encryption_content.dart';
export 'src/model/events/room_key_content.dart';
export 'src/model/events/room_key_request_content.dart';
export 'src/model/events/secret_storage_default_key_content.dart';
export 'src/model/events/secret_storage_key_content.dart';
export 'src/model/events/tombstone_content.dart';

==> matrix_api_lite-0.2.3.tar.gz: lib/matrix_api_lite.dart <==
/* MIT License
* 
* Copyright (C) 2019, 2020, 2021 Famedly GmbH
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/

library matrix_api_lite;

export 'src/matrix_api.dart';
export 'src/utils/logs.dart';
export 'src/utils/map_copy_extension.dart';
export 'src/utils/try_get_map_extension.dart';
export 'src/model/algorithm_types.dart';
export 'src/model/basic_event.dart';
export 'src/model/basic_event_with_sender.dart';
export 'src/model/basic_room_event.dart';
export 'src/model/device.dart';
export 'src/model/event_context.dart';
export 'src/model/event_types.dart';
export 'src/model/events_sync_update.dart';
export 'src/model/filter.dart';
export 'src/model/keys_query_response.dart';
export 'src/model/login_response.dart';
export 'src/model/login_types.dart';
export 'src/model/matrix_connection_exception.dart';
export 'src/model/matrix_event.dart';
export 'src/model/matrix_exception.dart';
export 'src/model/matrix_keys.dart';
export 'src/model/message_types.dart';
export 'src/model/notifications_query_response.dart';
export 'src/model/one_time_keys_claim_response.dart';
export 'src/model/open_graph_data.dart';
export 'src/model/open_id_credentials.dart';
export 'src/model/presence.dart';
export 'src/model/presence_content.dart';
export 'src/model/profile.dart';
export 'src/model/public_rooms_response.dart';
export 'src/model/push_rule_set.dart';
export 'src/model/pusher.dart';
export 'src/model/request_token_response.dart';
export 'src/model/room_alias_information.dart';
export 'src/model/room_keys_info.dart';
export 'src/model/room_keys_keys.dart';
export 'src/model/room_summary.dart';
export 'src/model/server_capabilities.dart';
export 'src/model/stripped_state_event.dart';
export 'src/model/supported_protocol.dart';
export 'src/model/supported_versions.dart';
export 'src/model/sync_update.dart';
export 'src/model/tag.dart';
export 'src/model/third_party_identifier.dart';
export 'src/model/third_party_location.dart';
export 'src/model/third_party_user.dart';
export 'src/model/timeline_history_response.dart';
export 'src/model/turn_server_credentials.dart';
export 'src/model/upload_key_signatures_response.dart';
export 'src/model/user_search_result.dart';
export 'src/model/well_known_information.dart';
export 'src/model/who_is_info.dart';
export 'src/model/auth/authentication_data.dart';
export 'src/model/auth/authentication_identifier.dart';
export 'src/model/auth/authentication_password.dart';
export 'src/model/auth/authentication_phone_identifier.dart';
export 'src/model/auth/authentication_recaptcha.dart';
export 'src/model/auth/authentication_third_party_identifier.dart';
export 'src/model/auth/authentication_three_pid_creds.dart';
export 'src/model/auth/authentication_token.dart';
export 'src/model/auth/authentication_types.dart';
export 'src/model/auth/authentication_user_identifier.dart';
export 'src/model/events/forwarded_room_key_content.dart';
export 'src/model/events/olm_plaintext_payload.dart';
export 'src/model/events/room_encrypted_content.dart';
export 'src/model/events/room_encryption_content.dart';
export 'src/model/events/room_key_content.dart';
export 'src/model/events/room_key_request_content.dart';
export 'src/model/events/secret_storage_default_key_content.dart';
export 'src/model/events/secret_storage_key_content.dart';
export 'src/model/events/tombstone_content.dart';
